# Changelog

<!--next-version-placeholder-->

## v1.5.0 (2022-05-29)
### Feature
* Monitoring feature ([#5](https://github.com/draganagrbic998/devops_offer_service/issues/5)) ([`3fecadb`](https://github.com/draganagrbic998/devops_offer_service/commit/3fecadbbbaffe84b29d4904b60af8df514de5145))

## v1.4.0 (2022-05-29)
### Feature
* Events, tracing and logging feature ([#3](https://github.com/draganagrbic998/devops_offer_service/issues/3)) ([`dd301ca`](https://github.com/draganagrbic998/devops_offer_service/commit/dd301ca16aae87dbd311dcc8b78c33213962427d))

### Fix
* Fix code analyses stage ([#4](https://github.com/draganagrbic998/devops_offer_service/issues/4)) ([`b7d5fd2`](https://github.com/draganagrbic998/devops_offer_service/commit/b7d5fd2c667acce6d425c83089d9330fe18c28af))

## v1.3.0 (2022-05-22)
### Feature
* Read/search offers feature ([#2](https://github.com/draganagrbic998/devops_offer_service/issues/2)) ([`dbec12c`](https://github.com/draganagrbic998/devops_offer_service/commit/dbec12cb423e3c1f1d86e4c0fb6d49a504f57433))

## v1.2.0 (2022-05-21)
### Feature
* Create offer feature ([#1](https://github.com/draganagrbic998/devops_offer_service/issues/1)) ([`3844546`](https://github.com/draganagrbic998/devops_offer_service/commit/3844546d6866e59b1592bb6ad90f00e77cd8ec9e))

## v1.1.0 (2022-05-21)
### Feature
* Init offer service ([`335ff72`](https://github.com/draganagrbic998/devops_offer_service/commit/335ff72ff54343dad2f3ee3e11a7aaaf2a45e7ce))
